===============
Getting started
===============

New to Django or MongoDB? Well, you came to the right place: read this material
to quickly get up and running.

.. toctree::
   :maxdepth: 1

   install
   configure

.. seealso::

    If you're new to Django_, you might want to start by getting an idea of
    what it's like.

    For a tutorial that covers using this library with MongoDB Atlas (a fully
    managed cloud database service that hosts MongoDB), read
    :doc:`mongodb:get-started`.

    Another excellent tutorial that covers Django in more detail is the
    :doc:`official Django tutorial <django:intro/tutorial01>`.

    .. _Django: https://www.djangoproject.org/
